==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/SampleReadme.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a README.md sample file. You are expected to manage this file after creation.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.438Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SampleReadme")
public class SampleReadme extends io.github.cdklabs.projen.SampleFile {

    protected SampleReadme(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SampleReadme(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleReadme(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.SampleReadmeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), props });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleReadme(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SampleReadme}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SampleReadme> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.SampleReadmeProps.Builder props;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) The contents.
         * <p>
         * Default: "# replace this"
         * <p>
         * @return {@code this}
         * @param contents The contents. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contents(final java.lang.String contents) {
            this.props().contents(contents);
            return this;
        }

        /**
         * (experimental) The name of the README.md file.
         * <p>
         * Default: "README.md"
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * // Example automatically generated from non-compiling source. May contain errors.
         * "readme.md"
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param filename The name of the README.md file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(final java.lang.String filename) {
            this.props().filename(filename);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.SampleReadme}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SampleReadme build() {
            return new io.github.cdklabs.projen.SampleReadme(
                this.project,
                this.props != null ? this.props.build() : null
            );
        }

        private io.github.cdklabs.projen.SampleReadmeProps.Builder props() {
            if (this.props == null) {
                this.props = new io.github.cdklabs.projen.SampleReadmeProps.Builder();
            }
            return this.props;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/SampleReadme.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a README.md sample file. You are expected to manage this file after creation.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.148Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SampleReadme")
public class SampleReadme extends io.github.cdklabs.projen.SampleFile {

    protected SampleReadme(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SampleReadme(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleReadme(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.SampleReadmeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), props });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SampleReadme(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SampleReadme}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SampleReadme> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.SampleReadmeProps.Builder props;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) The contents.
         * <p>
         * Default: "# replace this"
         * <p>
         * @return {@code this}
         * @param contents The contents. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contents(final java.lang.String contents) {
            this.props().contents(contents);
            return this;
        }

        /**
         * (experimental) The name of the README.md file.
         * <p>
         * Default: "README.md"
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * "readme.md"
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param filename The name of the README.md file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(final java.lang.String filename) {
            this.props().filename(filename);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.SampleReadme}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SampleReadme build() {
            return new io.github.cdklabs.projen.SampleReadme(
                this.project,
                this.props != null ? this.props.build() : null
            );
        }

        private io.github.cdklabs.projen.SampleReadmeProps.Builder props() {
            if (this.props == null) {
                this.props = new io.github.cdklabs.projen.SampleReadmeProps.Builder();
            }
            return this.props;
        }
    }
}
